*************************************************************
*GSP utilization analysis
*************************************************************
***Lines 5-12 must be run for file to work properly***
clear all
set more off
clear matrix
set maxvar 30000
version 18

*** Set the actual filepath here.***
cd "C:\users\Name\Documents\Release Files\Chapter 4 and Appendix E\GSP Modeling"

*************************************************
*Running basic regressions, best regime and HS section*
*************************************************
use "GSP_data.dta", clear

log using "pacis_GSP_summary_stats", replace

sum duty_ave
sum elig

log close
translate "pacis_GSP_summary_stats.smcl" "pacis_GSP_summary_stats.pdf"

log using "pacis_GSP_results.smcl", replace

*table E.1, regression (1)
qui fracreg logit ratio_gsputiliz duty_ave lnelig primary agri i.hssection_enc i.bestregime_enc i.year, vce(robust) noconstant
est store eq1
margins, dydx(lnelig duty_ave)

*table E.1, regression (2)
keep if pac_is==1
qui fracreg logit ratio_gsputiliz duty_ave lnelig primary agri, vce(robust)
est store pacisNoFE 
margins, dydx(lnelig duty_ave)

*table E.1, regression (3)
use "GSP_data.dta", clear
qui fracreg logit ratio_gsputiliz duty_ave lnelig primary agri pac_is##c.duty_ave pac_is##c.lnelig i.hssection_enc i.bestregime_enc i.year, vce(robust)
est store fullpacis
margins, dydx(lnelig duty_ave)

*table E.1, regression (4)
qui fracreg logit ratio_gsputiliz duty_ave lnelig primary agri pac_is##c.duty_ave pac_is##c.lnelig i.hssection_enc i.bestregime_enc i.year if year<2021, vce(robust)
est store noncovid
margins, dydx(lnelig duty_ave)

*outputs the data into the format seen in the modeling appendix: 
estout eq1 pacisNoFE fullpacis noncovid using "gsputiliz_hssection_bestregime.txt", cells(b(star fmt(3)) se(par fmt(5))) stats(N r2) indicate("Year FE = *.year" "Best Regime FE = *.bestregime_enc" "HS section FE = *.hssection_enc") style(tab) label replace

log close

translate "pacis_GSP_results.smcl" "pacis_GSP_results.pdf"

