*************************************************************
*Estimating Gravity:
*************************************************************
clear all
set more off
clear matrix
set maxvar 30000

*** Set the actual filepath here. Be sure that there is a Results subfolder. ***
* Run only line 11 if you want to run the rest of the file manually.
cd "C:\users\SampleFilePath"

**************************************************************
*Creating the dataset for running regressions*
**************************************************************

use "D_all_data.dta", clear

*Generate exporter and importer FE
*WARNING: This increases the size of the overall .dta file to close to 150GB.
egen exp_time=group(exporter year)
qui tab exp_time, gen(exp_time_fe)
egen imp_time=group(importer year)
qui tab imp_time, gen(imp_time_fe)

**************************************************************
*Running the model using PPML and domestic trade*
**************************************************************

forvalues i = 1(1)154 {
	*regression to do the Pacific Islands report analysis: 
	ppmlhdfe trade lndist2 contiguity common_language colonial_ties agree_fta gsp gsp_least_dev ln_DIST_INTRA SMCTRY if industry_id==`i', d absorb(exp_time imp_time) cluster(pair_id)
	predict trade_hat
	replace trade_hat_ppmlINTRA = trade_hat if industry_id==`i'
	drop trade_hat
	estimates store ppml`i'
}

*creating indexes used to rank sectors
gen gap_actual_ppmlINTRA = trade_hat_ppmlINTRA - trade
gen gap_ratio_ppmlINTRA = trade_hat_ppmlINTRA/trade

save "ppmlmodel_results_long.dta", replace
	*WARNING: This .dta file is close to 150GB.

**************************************************************
*Taking the results for the whole world and saving only the Pacific Island results*
**************************************************************

use "ppmlmodel_results_long.dta", clear

*only keeping data on the trade with the US
drop if exportToUSA!=1
order exporter importer industry_id trade trade_hat_ppml trade_hat_ppmlINTRA 
sort exporter industry_id

*Creating mean and max values of the data over the five year span
collapse (mean) trade trade_hat_ppmlINTRA_mean =trade_hat_ppmlINTRA gap_actual_ppmlINTRA_mean=gap_actual_ppmlINTRA gap_ratio_ppmlINTRA_mean=gap_ratio_ppmlINTRA (max) trade_hat_ppmlINTRA_max=trade_hat_ppmlINTRA gap_actual_ppmlINTRA_max=gap_actual_ppmlINTRA gap_ratio_ppmlINTRA_max=gap_ratio_ppmlINTRA, by(exporter exporter_name importer importer_name broad_sector industry_id industry_descr)

order exporter importer industry_id trade trade_hat_ppmlINTRA_mean 
sort exporter industry_id

sort exporter gap_actual_ppmlINTRA_mean
by exporter: gen top5_gap_actual = _N+1 - _n
sort exporter gap_ratio_ppmlINTRA_mean
by exporter: gen top5_gap_ratio = _N+1 - _n

*the end result here is a dataset of just the results from the model, with the relevant rankings based on the max and mean over the time window
save "ppmlmodel_results_PacIsTable.dta", replace

